@@ -3,7 +3,7 @@ package Hades;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 use Module::Generate;
 use Switch::Again qw/switch/;
 
@@ -34,7 +34,11 @@ sub run {
 				($copy =~ m/\(|\{|\[|\)|\}|\]/) ? do {
 					$ident .= $first_char;
 				} : do {
-					push @innerline, $ident;
+					if ($nested) {
+						push @innerline, $ident;
+					} else {
+						push @line, $ident;
+					}
 					$ident = '';
 				}
 			}
@@ -193,6 +197,10 @@ sub build_synopsis_or_abstract {
 sub build_sub_or_accessor_attributes {
 	my ($self, $name, $token, $meta) = @_;
 	my @ATTR = (
+		'default' => sub {
+			my $value = shift;
+			push @{$meta->{$name}->{caught}}, $value;
+		},
 		qr/^(\:around|\:ar)/ => sub {
 			$meta->{$name}->{meta} = 'MODIFY';
 			$token->[-1] =~ s/^\{(.*)\}$/$1/sg;
@@ -303,8 +311,8 @@ sub build_sub_or_accessor {
 		: $meta->{$name}->{meta} eq 'MODIFY'
 			? $self->build_modify($mg, $name, $meta)
 			: $self->build_sub($mg, $name, $meta);
-	$self->build_clearer($mg, $name, $meta) if $meta->{$name}->{clearer};
 	$self->build_predicate($mg, $name, $meta) if $meta->{$name}->{predicate};
+	$self->build_clearer($mg, $name, $meta) if $meta->{$name}->{clearer};
 	return $meta;
 }
 
@@ -314,15 +322,20 @@ sub build_accessor {
 	my $type = $self->build_coerce($name, '$value', $meta->{$name}->{coerce})
 	. $self->build_type($name, $meta->{$name}->{type}[0]);
 	my $trigger = $self->build_trigger($name, '$value', $meta->{$name}->{trigger});
-	my $code = qq|{
+	my $code = $self->build_accessor_code($name, $private, $type, $trigger);
+	$mg->accessor($name)->code($code)->clear_tests->test($self->build_tests($name, $meta->{$name}));
+	$meta->{$name}->{$_} && $mg->$_($self->replace_pe_string($meta->{$name}->{$_}, $name)) for qw/pod example/;
+}
+
+sub build_accessor_code {
+	my ($self, $name, $private, $type, $trigger) = @_;
+	return qq|{
 		my ( \$self, \$value ) = \@_; $private
 		if ( defined \$value ) { $type
 			\$self->{$name} = \$value; $trigger
 		}
 		return \$self->{$name};
 	}|;
-	$mg->accessor($name)->code($code)->clear_tests->test($self->build_tests($name, $meta->{$name}));
-	$meta->{$name}->{$_} && $mg->$_($self->replace_pe_string($meta->{$name}->{$_}, $name)) for qw/pod example/;
 }
 
 sub replace_pe_string {
@@ -377,13 +390,10 @@ sub build_sub {
 			}
 		}
 	}
-	$code = qq|{
-		my (\$self $params) = \@_; $subtype
-		$code;
-	}|;
+	$meta->{$name}->{params_explanation} = $params_explanation;
+	$code = $self->build_sub_code($name, $params, $subtype, $code);
 	$params =~ s/^,\s*//;
 	my $example = qq|\$obj->$name($params)|;
-
 	$mg->sub($name)->code($code)
 		->pod(qq|call $name method. Expects $params_explanation.|)
 		->example($example)
@@ -391,6 +401,14 @@ sub build_sub {
 	$meta->{$name}->{$_} && $mg->$_($self->replace_pe_string($meta->{$name}->{$_}, $name)) for qw/pod example/;
 }
 
+sub build_sub_code {
+	my ($self, $name, $params, $subtype, $code) = @_;
+	return qq|{
+		my (\$self $params) = \@_; $subtype
+		$code;
+	}|;
+}
+
 sub build_clearer {
 	my ($self, $mg, $name, $meta) = @_;
 	$mg->sub(qq|clear_$name|)
@@ -1016,7 +1034,7 @@ sub build_tests {
 		};
 	} : do {
 		$meta->{private} ? do {
-			push @tests, ['eval', qq|\$obj->name|, 'private method'];
+			push @tests, ['eval', qq|\$obj->$name|, 'private method'];
 		} : $meta->{param} && do {
 			my %test_data = map {
 				$_ => [
@@ -1065,7 +1083,7 @@ Hades - Less is more, more is less!
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =cut
 
@@ -1248,7 +1266,7 @@ Declare the classes Synopsis.
 	Kosmos {
 		synopsis {
 			Schetika me ton Kosmos
-				
+
 				Kosmos->new;
 		}
 	}
@@ -1307,7 +1325,7 @@ Declare the classes additional tests.
 
 	Kosmos {
 		test {
-			[ 
+			[
 				['ok', 'my $obj = Kosmos->new'],
 				['is', '$obj->dokimi', undef]
 			]
